@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: statistics
 version: 0.13.2.3
-id: statistics-0.13.2.3-d6ed6ed84339731797ff8544ac5c55da
-key: stati_3ZZ8y45xeKcLi5IxoNZCFq
+id: statistics-0.13.2.3-781c9ad2296cc7a41c5283491bb54b0b
+key: stati_5gFPd48mSRD9KxpJPM1IFG
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -63,19 +63,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/statistics-0.13.2.3
-hs-libraries: HSstatistics-0.13.2.3-3ZZ8y45xeKcLi5IxoNZCFq
+hs-libraries: HSstatistics-0.13.2.3-5gFPd48mSRD9KxpJPM1IFG
 depends:
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
     math-functions-0.1.5.2-cca3e664aeca2116145d4ae702f767c6
-    monad-par-0.3.4.7-775d7d36eed9307a352844e8cf65ec62
-    mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
+    monad-par-0.3.4.7-71f3c038a9542ac299ca5b790fa5b12a
+    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    vector-algorithms-0.7.0.1-35e55e2e8e51824728ed456b5a330a6b
+    vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
     vector-binary-instances-0.2.1.1-c0febfb5ca69d46d3d7932a3e5b87de1
 haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
 haddock-html: /usr/share/doc/haskell-statistics/html
